Token

Enum Token 

pub enum Token<'a> {
Show 33 variants If, Then, Else, Rec, Let, In, True, False, Match, Ident(&'a str), Float(f64), Int(i64), EqEq, BangEq, LtEq, GtEq, Lt, Gt, AndAnd, PipePipe, Bang, Plus, Minus, Star, Slash, Caret, Pipe, Eq, LParen, RParen, StrongArrow, WhiteSpace, Error,
}

Variants



If



Then



Else



Rec



Let



In



True



False



Match



Ident(&'a str)



Float(f64)



Int(i64)



EqEq



BangEq



LtEq



GtEq



Lt



Gt



AndAnd



PipePipe



Bang



Plus



Minus



Star



Slash



Caret



Pipe



Eq



LParen



RParen



StrongArrow



WhiteSpace



Error